@@ -155,7 +155,7 @@ class Client:
         self.cache_max_size = cache_max_size
 
         self.http = None  # set in method login()
-        self._ready = asyncio.Event(loop=loop)
+        self._ready = asyncio.Event()
         self.correct_tags = correct_tags
 
         # cache
@@ -199,9 +199,9 @@ class Client:
         """Closes the HTTP connection
         """
         LOG.info("Clash of Clans client logging out...")
+        self.dispatch("on_client_close")
         self.loop.run_until_complete(self.http.close())
         self.loop.close()
-        self.dispatch("on_client_close")
 
     def dispatch(self, event_name: str, *args, **kwargs):
         """Dispatches an event listener matching the `event_name` parameter."""
@@ -213,7 +213,7 @@ class Client:
             return
 
         if asyncio.iscoroutinefunction(fctn):
-            asyncio.ensure_future(fctn(*args, **kwargs), loop=self.loop)
+            self.loop.create_task(fctn(*args, **kwargs))
         else:
             fctn(*args, **kwargs)
 
@@ -497,10 +497,6 @@ class Client:
         --------
         :class:`ClanWarLeagueGroup`
             The clan's war league group.
-
-        Raises
-        ------
-        :exc:`PrivateWarLog`: The clan's war log is private.
         """
         # pylint: disable=protected-access
         if not issubclass(cls, ClanWarLeagueGroup):
@@ -1042,3 +1038,25 @@ class Client:
             raise TypeError("cls must be a subclass of Player.")
 
         return PlayerIterator(self, player_tags, cls=cls, **kwargs)
+
+    @corrected_tag(arg_name="player_tag")
+    async def verify_player_token(self, player_tag: str, token: str):
+        """Verify player API token that can be found from the game settings.
+
+        This can be used to check that players own the game accounts they claim to own
+        as they need to provide the one-time use API token that exists inside the game.
+
+        Parameters
+        ----------
+        player_tag : str
+            The player tag to verify.
+        token : str
+            The player's API token to verify.
+
+        Returns
+        --------
+        :class:`bool`
+            Whether the player tag and API token were a valid match.
+        """
+        data = await self.http.verify_player_token(player_tag, token)
+        return data and data["status"] == "ok" or False
