@@ -117,6 +117,8 @@ class Troop:
         :class:`int`: The overall max level of the troop; excluding townhall limitations.
     village:
         :class:`str`: Either ``home`` or ``builderBase``.
+    is_active:
+        :class:`bool`: Returns a boolean which indicates whether a super troop is active.
     """
 
     __slots__ = (
@@ -124,6 +126,7 @@ class Troop:
         "level",
         "max_level",
         "village",
+        "is_active",
     )
 
     def __str__(self):
@@ -133,6 +136,7 @@ class Troop:
         attrs = [
             ("name", self.name),
             ("level", self.level),
+            ("is_active", self.is_active),
         ]
         return "<%s %s>" % (self.__class__.__name__, " ".join("%s=%r" % t for t in attrs),)
 
@@ -144,6 +148,7 @@ class Troop:
         self.level = data["level"]
         self.max_level = data["maxLevel"]
         self.village = data["village"]
+        self.is_active = data.get("superTroopIsActive")
 
     @property
     def is_max(self) -> bool:
@@ -672,3 +677,35 @@ class WarLeague:
 
     def __eq__(self, other):
         return isinstance(self, other.__class__) and other.id == self.id
+
+
+class ChatLanguage:
+    """Represents a clan's chat language.
+
+    Attributes
+    ----------
+    id: :class:`int`: The language's unique ID
+    name: :class:`str`: The language's full name, for example ``English``.
+    language_code: :class:`str` The language's abbreviated code, for example ``EN``.
+    """
+    __slots__ = (
+        "id",
+        "name",
+        "language_code"
+    )
+
+    def __init__(self, *, data):
+        # pylint: disable=invalid-name
+        self.id = data["id"]
+        self.name = data["name"]
+        self.language_code = data["languageCode"]
+
+    def __repr__(self):
+        return "<%s id=%s name=%s>" % (self.__class__.__name__, self.id, self.name)
+
+    def __str__(self):
+        return self.name
+
+    def __eq__(self, other):
+        return isinstance(self, other.__class__) and other.id == self.id
+
